Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/server.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'lib/autoloader.php')
-rw-r--r--lib/autoloader.php5
1 files changed, 3 insertions, 2 deletions
diff --git a/lib/autoloader.php b/lib/autoloader.php
index c8eebee3e0c..a29b9aece79 100644
--- a/lib/autoloader.php
+++ b/lib/autoloader.php
@@ -38,6 +38,7 @@ namespace OC;
use \OCP\AutoloadNotAllowedException;
use OCP\ILogger;
+use OCP\ICache;
class Autoloader {
/** @var bool */
@@ -182,9 +183,9 @@ class Autoloader {
/**
* Sets the optional low-latency cache for class to path mapping.
*
* @param \OC\Memcache\Cache $memoryCache Instance of memory cache.
*/
- public function setMemoryCache(\OC\Memcache\Cache $memoryCache = null): void {
+ public function setMemoryCache(ICache $memoryCache = null): void {
$this->memoryCache = $memoryCache;
}
}
@@ -182,9 +183,9 @@ class Autoloader {
* Sets the optional low-latency cache for class to path mapping.
*
- * @param \OC\Memcache\Cache $memoryCache Instance of memory cache.
+ * @param ICache $memoryCache Instance of memory cache.
*/